@@ -4,9 +4,28 @@ use 5.028001;
 use strict;
 use warnings;
 
-our @ISA = qw();
+require Exporter;
 
-our $VERSION = '3.7';
+our @ISA = qw(Exporter);
+
+# Items to export into callers namespace by default. Note: do not export
+# names by default without a very good reason. Use EXPORT_OK instead.
+# Do not simply export all your public functions/methods/constants.
+
+# This allows declaration	use voiceIt::voiceIt2 ':all';
+# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
+# will save memory.
+our %EXPORT_TAGS = ( 'all' => [ qw(
+	
+) ] );
+
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+
+our @EXPORT = qw(
+	
+);
+
+our $VERSION = '3.8';
 
 
 # Preloaded methods go here.
@@ -32,6 +51,11 @@ unedited.
 
 Blah blah blah.
 
+=head2 EXPORT
+
+None by default.
+
+
 
 =head1 SEE ALSO
 
